@@ -58,6 +58,7 @@ function (formula, data = parent.frame(), id=NULL, FUN = mean, keep.names=FALSE,
     group <- attr(terms(ff), "term.labels")
 
     resp <- respny
+    resp<-gsub(" ","",resp) ## A hack to delete spaces...
     colnames(yy) <- resp
     groupList <- NULL
 
@@ -69,6 +70,9 @@ function (formula, data = parent.frame(), id=NULL, FUN = mean, keep.names=FALSE,
       varPrefix <- fun.names
     }
 
+    ##print("RESPONSES:"); print(resp)
+
+
     
     if (keep.names){
       if (length(fun.names)==1)
@@ -81,7 +85,9 @@ function (formula, data = parent.frame(), id=NULL, FUN = mean, keep.names=FALSE,
       newNames <- unlist(lapply(varPrefix, paste, resp, sep = "."))
     }
 
+    ##print(newNames)
 
+    
     extra <- which(is.na(match(colnames(yy), names(d))))
     d <- cbind(d, yy[, extra, drop = FALSE])
     
